AdFormat enum

Banner format

Inheritance
Available extensions

Values

Banner format

const AdFormat('BANNER')
interstitial → const AdFormat

Interstitial format

const AdFormat('INTERSTITIAL')
videoOutStreamBanner → const AdFormat

Video format

const AdFormat('VIDEO_OUT_STREAM_BANNER')
infiniteScroll → const AdFormat

Infinite Scroll format

const AdFormat('INFINITE_SCROLL')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
Internal name of the ad format.
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromName(String name) → AdFormat

Constants

values → const List<AdFormat>
A constant List of the values in this enum, in order of their declaration.