AppOpenInterstitialEventListener class mixin

The lifecycle of an App Open Interstitial follows these stages:

  1. onLoaded Called when the App Open Interstitial is loaded and ready to be shown. Or If this goes wrong, the onFailedToLoad when this happens the factory marks the object for deletion.
  2. onFailedToLoad: Called when the ad fails to load. This could be due to network issues, invalid configurations, or lack of available ad inventory.
  3. onOpen Called when the interstitial screen is launched on top of the app, in case of error the onAdFailedToShowFullScreen will be called.
  4. onImpression This means it did finish loading the creatives on the screen and they can be clicked.
  5. onClick The ad opens another Intent with the advertiser link.
  6. onAdDismissedFullScreenContent Everything went right and the user just closed the fullscreen ad.
Implemented types

Constructors

AppOpenInterstitialEventListener.callbacks({AdFailedToLoadCallback? onAdFailedToShowFullScreenCallback, AdVoidCallback? onAdDismissedFullScreenContentCallback, AdVoidCallback? onClickCallback, AdFailedToLoadCallback? onFailedToLoadCallback, AdVoidCallback? onImpressionCallback, AdVoidCallback? onLoadedCallback, AdVoidCallback? onOpenCallback})
The helper factory function, which can be used to listen directly and in-place to specific events without the need to extend, mix, or implement AppOpenInterstitialEventListener.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAdDismissedFullScreenContent() → void
onAdFailedToShowFullScreen(String message) → void
onClick() → void
Called when an ad is clicked.
override
onFailedToLoad(String message) → void
Called when an ad is failed to load.
override
onImpression() → void
Called when an ad is shown on the screen for the first time.
override
onLoaded() → void
Called when an ad is loaded.
override
onOpen() → void
Called when an ad starts an Intent.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited