R89OutStream class

A wrapper widget on R89AdFactory.createVideoOutStreamBanner to create banner ads with format AdFormat.videoOutStreamBanner.

R89OutStream(
Inheritance
Annotations
  • @Deprecated('Video Outstream Banner is deprecated and will soon be removed, please use Banner Format as it provides both video and banner ads now.')

Constructors

R89OutStream({required String configurationId, BannerEventListener? lifecycleCallbacks, Key? key})
Creates a video ad widget with specified configurationId and optional lifecycleCallbacks.
const

Properties

configurationId → String
This Id used to fetch the unit configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lifecycleCallbacks → BannerEventListener?
Optional parameter to listen ad's related events see the BannerEventListener to know when the callbacks are called.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited