R89SDK class final
This class is an entry point to the RF89 SDK.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- adFactory → R89AdFactory
-
An entry point to create Ad widgets.
no setter
-
routeObserver
→ RouteObserver<
Route> -
A NavigatorObserver that uses by the R89SDK to automatically handle
lifecycle of created advertisements.
When a route is popped all advertisements related to that route are get destroyed.
no setter
- singleTagConfiguration → SingleTagConfig
-
An entry point to start the single tag configuration for the screens.
no setter
Static Methods
-
disableCMP(
) → Future< void> - This method will disable the CMP, this means that you will be required to use you own CMP and after your CMP is finished you can Initialize the SDK normally
-
exportCmpString(
) → Future< String> - Exports the current CMP string representing the user's consent preferences.
-
getInitializationState(
) → Future< SdkInitState> - Returns the current SDK initialization state.
-
initialize(
{required String pubUUID, required String apiKey, required bool singleTag, InitializationEvents? initializationEvents}) → Future< void> - This is to use Auto Configuration where the SDK will fetch the configuration from the server, and apply those to itself. It still requires using the R89AdFactory to place the ads in the views.
-
isDebug(
) → Future< bool> - Returns whether SDK debug mode is currently enabled.
-
reOpenConsent(
) → Future< void> - Reopens the CMP selection screen for the user to change settings
-
resetConsent(
) → Future< void> - Deletes all local data saved about the CMP. Next time the CMP is asked if it needs to show or not, it will require showing since all consent that was previously given has been deleted.
-
setDebug(
) → Future< void> - Enables SDK debug mode.
-
setLogLevel(
LogLevel level) → Future< void> -
shouldDisplayPrivacyOptions(
ShouldDisplayPrivacyOptionsCallback callback) → Future< void> - Checks if you ever should call reOpenConsent or resetConsent