SingleTagConfig class abstract

This class is an entry point to start the manual configuration of the tags.

Constructors

SingleTagConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialRouteName ← String
Specify the initial route name, the by default the screen name will be taken from the first provided AdScreenConfig addAdScreenConfig, or '/' if no manual AdScreenConfig is provided.
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAdScreenConfig({required AdScreenConfig adScreenConfig}) → void
Adds the instance of AdScreenConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited