R89AdFactory class abstract interface

API exposing creation and management of ad widgets.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBanner({required String configurationId, BannerEventListener? lifecycleCallbacks}) Widget
Creates a banner type ad widget. Banner is a fixed size static ad. First, we cache the ad, load it, and when it loads, we display it.
createInfiniteScroll({required String configurationId, InfiniteScrollEventListener? lifecycleCallbacks}) int
Returns an infiniteScrollId that should be used next by getInfiniteScrollAdForIndex method to create a ad widget, the infiniteScrollId serves as a group id for the advertisements inside the scrollable widget, such as ListView, GridView, and other sliver based scrolls.
createInterstitial({required String configurationId, required R89VoidCallback onComplete, InterstitialEventListener? lifecycleCallbacks}) Future<int>
Creates and displays an Interstitial ad on top of flutter's host screen. You can also configure what to do after the Interstitial in onComplete.
createRewarded({required String configurationId, required R89VoidCallback onComplete, required R89Arg1Callback<RewardItem> rewardReceived, RewardedEventListener? lifecycleCallbacks}) Future<int>
Creates a Rewarded ad, which can be shown whenever you want to provide a reward in exchange for watching an ad.
createRewardedInterstitial({required String configurationId, required R89VoidCallback onComplete, required R89Arg1Callback<RewardItem> rewardReceived, RewardedEventListener? lifecycleCallbacks}) Future<int>
Creates a Rewarded Interstitial ad, which can be shown whenever you want to provide a reward in exchange for watching an ad.
createTag({required String tag, Widget? child, int? itemIndex, Key? key}) Widget
This widget places the advertisement by using the provided tag and route name according to predefined advertisement configurations for a screen and a tag.
createVideoOutStreamBanner({required String configurationId, BannerEventListener? lifecycleCallbacks}) Widget
Create a video banner (OutStream) type ad widget. Video banner (OutStream) is a fixed size video ad. First, we cache the ad, load it, and when it loads, we display it.
destroyInterstitial(int id) Future<void>
This method destroys the interstitial for a given interstitialId, see R89AdFactory.createInterstitial method.
getInfiniteScrollAdForIndex({required int infiniteScrollId, required int itemIndex, BannerEventListener? lifecycleCallbacks}) Widget
Creates Ad widget or an empty widget SizedBox.shrink(), depending from provided itemIndex, by that the SDK will automatically decides whether to display an ad for a given position or not. infiniteScrollId is a group id of the advertisements inside the scrollable widget, and can be get by using createInfiniteScroll method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAppOpenEnabled({required bool enabled}) Future<void>
Enables or disables the App Open ad.
show(int id) Future<void>
This method displays the interstitial for a given interstitialId, see R89AdFactory.createInterstitial method.
subscribeToAppOpen(AppOpenInterstitialEventListener? lifecycleCallbacks) → void
Subscribes the given lifecycleCallbacks to receive global App Open Ad events. This allows external listeners to be notified of App Open Ad lifecycle events such as loading, impressions, clicks, and dismissals.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited