createVideoOutStreamBanner abstract method

  1. @Deprecated('Video Outstream Banner is deprecated and will soon be removed, please use Banner Format as it provides both video and banner ads now.')
Widget createVideoOutStreamBanner({
  1. required String configurationId,
  2. BannerEventListener? lifecycleCallbacks,
})

Create a video banner (OutStream) type ad widget. Video banner (OutStream) is a fixed size video ad. First, we cache the ad, load it, and when it loads, we display it.

configurationId ID used to fetch the unit configuration. lifecycleCallbacks is option see the BannerEventListener to know when the callbacks are called.

Implementation

@Deprecated('Video Outstream Banner is deprecated and will soon be removed, please use Banner Format as it provides both video and banner ads now.')
Widget createVideoOutStreamBanner({
  required String configurationId,
  BannerEventListener? lifecycleCallbacks,
});