SdkInitState enum
Represents the lifecycle states of the SDK initialization process.
Values
- notInitialized → const SdkInitState
-
SDK initialization has not been started.
- startedInitialization → const SdkInitState
-
SDK initialization has started.
- startedDataFetch → const SdkInitState
-
Remote or local (debug-only) data fetching has started.
- dataFetchSuccess → const SdkInitState
-
Data fetch completed successfully.
When this state is reached, all subsequent initialization steps (e.g. CMP setup and final initialization) are expected to be executed.
- dataFetchFailed → const SdkInitState
-
Data fetch failed.
When this state is reached, no further initialization steps (e.g. CMP setup or final initialization) should be executed.
- startedCmp → const SdkInitState
-
Consent Management Platform (CMP) flow has started.
- cmpFinished → const SdkInitState
-
Consent Management Platform (CMP) flow has finished.
- initializationFinished → const SdkInitState
-
SDK initialization has completed successfully and the SDK is ready for use.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SdkInitState> - A constant List of the values in this enum, in order of their declaration.